@@ -31,7 +31,6 @@ $IS64BIT = 0;
     $asmformat =~ /(.*)\-(.*)\-(.*)\-(.*)\-(.*)\-(.*)\-(.*)\-(.*)\-(.*)\-(.*)\-(.*)\-(.*)/);
 
 if (0) {
-print "$asmformat\n";
 print "CONFIG: $CONFIG\n";
 print "TEXT: $TEXT\n";
 print "GLOBAL: $GLOBAL\n";
@@ -103,11 +102,7 @@ while (<INPUT>) {
 }
 
 if ($GNU_STACK == 1) {
-    if ($asmarch eq "ARM") {
-        print OUTPUT "\n\t.section\t.note.GNU-stack,\"\",\%progbits\n";
-    } else {
-        print OUTPUT "\n\t.section\t.note.GNU-stack,\"\",\@progbits\n";
-    }
+    print OUTPUT "\n\t.section\t.note.GNU-stack,\"\",\@progbits\n";
 }
 
 close(INPUT);
